#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-extra
version:              1.3.8
visibility:           public
id:                   conduit-extra-1.3.8-1DWgHn4WIu2hT6xloHtnR
key:                  conduit-extra-1.3.8-1DWgHn4WIu2hT6xloHtnR
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.

category:             Data, Conduit
abi:                  b0dbf911a5b4590c77237b47003742d8
exposed:              True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib

import-dirs:          /usr/lib/ghc-9.6.6/site-local/conduit-extra-1.3.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/conduit-extra-1.3.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/conduit-extra-1.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-extra
hs-libraries:         HSconduit-extra-1.3.8-1DWgHn4WIu2hT6xloHtnR
depends:
    async-2.2.6-L49doqolqOiLsPy3OvdI1h
    attoparsec-0.14.4-9CcJCC4ORykBmnSiMZ6uwP base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-534uwm1BQ035a3x29nwuhR
    directory-1.3.8.5 filepath-1.4.300.1
    network-3.1.4.0-tP2o8Wry2b3nJpuPXPLoR
    primitive-0.9.1.0-BFOZgwmJzy9HvkVKyhwLqr process-1.6.19.0
    resourcet-1.2.6-5o8OKNGoLEyGu1zh0QIf5q stm-2.5.1.0
    streaming-commons-0.2.3.1-JJ0HqrqWmbwFwDZTTxD1qw text-2.0.2
    transformers-0.6.1.0 typed-process-0.2.13.0-3njdao0UBftC0M0fDGFJH2
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock

haddock-html:         /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

